<?php

// This function is used to create a new folder if folder not exist in the path
function create_folder($path) {
    if (!file_exists($path)) {
        // provide 0755 permision to create the folder
        mkdir($path, 0755, TRUE);
    }
}

/* Purpose: This function is used to create images of the size which is passed in parameters.
 * Parameters: $source path: This contains the path of the original image
 *            $target_path: This contains the temp path of the new image which need to be created.
 *            $file_type: This contains the image extension (jpg/gif/png)
 *            $thumb_width: It is the width of the thumb image.
 *            $thumb_height: It is the height of the thumb image
 * Return: This function return TRUE if the image created succesfully else return FALSE
 */

function create_thumbnail($source_path, $target_path, $file_type, $thumb_width, $thumb_height) {
    if ($file_type == 'jpeg' || $file_type == 'jpg') {
        $source = imagecreatefromjpeg($source_path);
    } else if ($file_type == 'png') {
        $source = imagecreatefrompng($source_path);
    } else if ($file_type == 'gif') {
        $source = imagecreatefromgif($source_path);
    }

    // get the width of the original image
    $width = imagesx($source);

    // get the height of the original image
    $height = imagesy($source);

    // Create a black image of thumb image size
    $thumb_image = imagecreatetruecolor($thumb_width, $thumb_height);

    // It copy and resize part of an original image and resampled in thumb image to create a reduced size image of the original image
    imagecopyresampled($thumb_image, $source, 0, 0, 0, 0, $thumb_width, $thumb_height, $width, $height);

    // creates a JPEG file from the given image and save it in the targeted folder.
    if (imagejpeg($thumb_image, $target_path, 90)) {
        // destroy the images to free the memory associate with them
        imagedestroy($thumb_image);
        imagedestroy($source);
        return TRUE;
    } else {
        return FALSE;
    }
}

?>